package netbsd

import (
	"fmt"
	"log"
	"strings"

	"codeberg.org/hyperreal/go-torrent-helper/common"
	"github.com/PuerkitoBio/goquery"
	"github.com/hekmon/transmissionrpc"
)

type NetBSD struct {
	NameSubstr string
	Relver     string
	URL        string
}

func (nb NetBSD) AddNewTorrents(transmissionbt *transmissionrpc.Client) error {
	// Send HTTP GET request and receive response
	nb.URL = fmt.Sprintf("https://cdn.netbsd.org/pub/NetBSD/NetBSD-%s/images", nb.Relver)
	respBody, err := common.GetResponse(nb.URL)
	if err != nil {
		return err
	}

	// Get a goquery doc from response body
	doc, err := goquery.NewDocumentFromReader(respBody)
	if err != nil {
		return err
	}

	// Extract torrent URLs from web page source
	var torrentURLs []string
	doc.Find("a").Each(func(i int, s *goquery.Selection) {
		if strings.Contains(s.Text(), ".torrent") {
			torrentURLs = append(torrentURLs, fmt.Sprintf("%s/%s", nb.URL, s.Text()))
		}
	})

	// Add torrents to Transmission instance
	for _, torrentURL := range torrentURLs {
		torrent, err := transmissionbt.TorrentAdd(&transmissionrpc.TorrentAddPayload{
			Filename: &torrentURL,
		})
		if err != nil {
			return err
		}

		log.Printf("%s added\n", *torrent.Name)
	}

	return nil
}

func (nb NetBSD) RemoveOldTorrents(transmissionbt *transmissionrpc.Client) error {
	if err := common.RemoveTorrents(nb.NameSubstr, nb.Relver, transmissionbt); err != nil {
		return err
	}

	return nil
}
